@@ -1,5 +1,5 @@
 package List::Objects::WithUtils::Role::Array::Typed;
-$List::Objects::WithUtils::Role::Array::Typed::VERSION = '2.024001';
+$List::Objects::WithUtils::Role::Array::Typed::VERSION = '2.025001';
 use strictures 2;
 
 use Carp ();
@@ -28,10 +28,6 @@ around new => sub {
     $type = shift;
   }
 
-  Carp::confess "Expected a Type::Tiny type but got '$type'"
-    unless Scalar::Util::blessed($type)
-    && $type->isa('Type::Tiny');
-
   my $self = [];
   tie @$self, 'Type::Tie::ARRAY', $type;
   push @$self, @_;
@@ -72,7 +68,8 @@ List::Objects::WithUtils::Role::Array::Typed - Type-checking array behavior
 This role makes use of L<Type::Tie> to add type-checking behavior to
 L<List::Objects::WithUtils::Role::Array> consumers.
 
-The first argument passed to the constructor should be a L<Type::Tiny> type:
+The first argument passed to the constructor should be a L<Type::Tiny> type
+(or other object conforming to L<Type::API>, as of C<v2.25>):
 
   use Types::Standard -all;
   my $arr = array_of Str() => qw/foo bar baz/;
